@@ -17,9 +17,5 @@ class Graph(models.Model):
 		unique_together = ("name", "group")
 		ordering = ['-priority']
 
-	def clean(self):
-		try:
-			render(self.command, 'PNG')
-		except RRDError as e:
-			raise ValidationError({'command':e.message})
-
+	def render(self, format):
+		return render(self.command, format)
